dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.functional module — dtw_loss_functions documentation

# dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.functional module

dtw_loss_functions.soft_dtw_implementations.soft_dtw_cuda_ron.functional.softdtw(x: Tensor, y: Tensor, *, gamma: float = 1.0, bandwidth: float | None = None, normalize: bool = False, dist: str = 'sqeuclidean', fused: bool | None = None) → Tensor

  Convenience functional API.

  x: (B,N,D) or (N,D) y: (B,M,D) or (M,D) fused: None (auto), True (require fused), False (never fused) returns: (B,)